@@ -174,6 +174,7 @@ public:
                     m_frames.insert(it.key(), data);
                 }
             }
+            m_nextFreeFrameId = rhs->m_nextFreeFrameId;
         }
 
         if (rhs->m_lodData) {
@@ -261,6 +262,14 @@ private:
 
 public:
 
+    int getNextFrameId() {
+        int frameId = 0;
+        while (m_frames.contains(frameId = m_nextFreeFrameId++));
+        KIS_SAFE_ASSERT_RECOVER_NOOP(!m_frames.contains(frameId));
+
+        return frameId;
+    }
+
     int createFrame(bool copy, int copySrc, const QPoint &offset, KUndo2Command *parentCommand)
     {
         KIS_ASSERT_RECOVER(parentCommand) {
@@ -294,7 +303,7 @@ public:
             data->setY(offset.y());
         }
 
-        int frameId = nextFreeFrameId++;
+        int frameId = getNextFrameId();
 
         KUndo2Command *cmd =
             new FrameInsertionCommand(&m_frames,
@@ -507,7 +516,7 @@ private:
     mutable QMutex m_dataSwitchLock;
 
     FramesHash m_frames;
-    int nextFreeFrameId;
+    int m_nextFreeFrameId;
 };
 
 const KisDefaultBoundsSP KisPaintDevice::Private::transitionalDefaultBounds = new KisDefaultBounds();
@@ -519,7 +528,7 @@ KisPaintDevice::Private::Private(KisPaintDevice *paintDevice)
       basicStrategy(new KisPaintDeviceStrategy(paintDevice, this)),
       isProjectionDevice(false),
       m_data(new Data(paintDevice)),
-      nextFreeFrameId(0)
+      m_nextFreeFrameId(0)
 {
 }
 
@@ -768,7 +777,7 @@ void KisPaintDevice::Private::uploadFrame(int dstFrameId, KisPaintDeviceSP srcDe
 void KisPaintDevice::Private::uploadFrameData(DataSP srcData, DataSP dstData)
 {
     if (srcData->colorSpace() != dstData->colorSpace() &&
-        !(*srcData->colorSpace() == *dstData->colorSpace())) {
+        *srcData->colorSpace() != *dstData->colorSpace()) {
 
         KUndo2Command tempCommand;
 
