@@ -29,6 +29,9 @@ public:
     KisCurvePaintOpSettings();
     virtual ~KisCurvePaintOpSettings();
 
+    void setPaintOpSize(qreal value) Q_DECL_OVERRIDE;
+    qreal paintOpSize() const Q_DECL_OVERRIDE;
+
     virtual bool paintIncremental();
 
     QList<KisUniformPaintOpPropertySP> uniformProperties();
